[jbossws-commits] JBossWS SVN: r3956 - in trunk: integration/jboss40/src/main/resources and 9 other directories.

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Thu Jul 19 14:03:55 EDT 2007


Author: thomas.diesler at jboss.com
Date: 2007-07-19 14:03:54 -0400 (Thu, 19 Jul 2007)
New Revision: 3956

Added:
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/EndpointAddressDeploymentAspect.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/CXFServletExt.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/DescriptorDeploymentAspect.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/ServletControllerExt.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDEndpoint.java
Removed:
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireConfigurableServletExt.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServicesDeploymentAspect.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServletControllerExt.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDService.java
Modified:
   trunk/build/version.properties
   trunk/integration/jboss40/src/main/resources/jbossws-jboss40-config.xml
   trunk/integration/jboss42/src/main/resources/jbossws-jboss42-config.xml
   trunk/integration/jboss50/src/main/resources/jbossws-jboss50.deployer/META-INF/jbossws-deployer-beans.xml
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/BasicEndpoint.java
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java
   trunk/integration/xfire/.classpath
   trunk/integration/xfire/ant-import/build-testsuite.xml
   trunk/integration/xfire/ant-import/build-thirdparty.xml
   trunk/integration/xfire/ant-import/macros-deploy-xfire.xml
   trunk/integration/xfire/build.xml
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerEJB3.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerJSE.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/RequestHandlerImpl.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/WebAppDesciptorModifierImpl.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBean.java
   trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBeans.java
   trunk/integration/xfire/src/main/resources/jbossws-xfire-config.xml
   trunk/integration/xfire/version.properties
   trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/eardeployment/EarTestCase.java
Log:
Migrate to Apache-CXF

Modified: trunk/build/version.properties
===================================================================
--- trunk/build/version.properties	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/build/version.properties	2007-07-19 18:03:54 UTC (rev 3956)
@@ -27,7 +27,7 @@
 junit=3.8.1
 stax-api=1.0
 sun-jaf=1.1
-sun-jaxb=2.1.3
+sun-jaxb=2.1.4
 sun-jaxrpc=1.1
 sun-jaxws=2.1.1
 sun-servlet=2.5

Modified: trunk/integration/jboss40/src/main/resources/jbossws-jboss40-config.xml
===================================================================
--- trunk/integration/jboss40/src/main/resources/jbossws-jboss40-config.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/jboss40/src/main/resources/jbossws-jboss40-config.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -89,6 +89,11 @@
     <property name="provides">ContextRoot</property>
   </bean>
   
+  <bean name="WSEndpointAddressDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointAddressDeploymentAspect">
+    <property name="requires">URLPattern</property>
+    <property name="provides">EndpointAddress</property>
+  </bean>
+  
   <bean name="WSEndpointHandlerDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointHandlerDeploymentAspect">
     <property name="provides">ContainerEndpointHandler</property>
     <property name="invocationHandler">
@@ -170,6 +175,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>
@@ -186,6 +192,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>

Modified: trunk/integration/jboss42/src/main/resources/jbossws-jboss42-config.xml
===================================================================
--- trunk/integration/jboss42/src/main/resources/jbossws-jboss42-config.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/jboss42/src/main/resources/jbossws-jboss42-config.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -89,6 +89,11 @@
     <property name="provides">ContextRoot</property>
   </bean>
   
+  <bean name="WSEndpointAddressDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointAddressDeploymentAspect">
+    <property name="requires">URLPattern</property>
+    <property name="provides">EndpointAddress</property>
+  </bean>
+  
   <bean name="WSEndpointHandlerDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointHandlerDeploymentAspect">
     <property name="provides">ContainerEndpointHandler</property>
     <property name="invocationHandler">
@@ -169,6 +174,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>
@@ -185,6 +191,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>

Modified: trunk/integration/jboss50/src/main/resources/jbossws-jboss50.deployer/META-INF/jbossws-deployer-beans.xml
===================================================================
--- trunk/integration/jboss50/src/main/resources/jbossws-jboss50.deployer/META-INF/jbossws-deployer-beans.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/jboss50/src/main/resources/jbossws-jboss50.deployer/META-INF/jbossws-deployer-beans.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -143,6 +143,11 @@
     <property name="provides">ContextRoot</property>
   </bean>
   
+  <bean name="WSEndpointAddressDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointAddressDeploymentAspect">
+    <property name="requires">URLPattern</property>
+    <property name="provides">EndpointAddress</property>
+  </bean>
+  
   <bean name="WSEndpointHandlerDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointHandlerDeploymentAspect">
     <property name="provides">ContainerEndpointHandler</property>
     <property name="invocationHandler">
@@ -213,6 +218,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>
@@ -229,6 +235,7 @@
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
         <inject bean="WSContextRootDeploymentAspect"/>
+        <inject bean="WSEndpointAddressDeploymentAspect"/>
         <inject bean="WSEndpointHandlerDeploymentAspect"/>
         <inject bean="WSEndpointLifecycleDeploymentAspect"/>
         <inject bean="WSEndpointMetricsDeploymentAspect"/>

Modified: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/BasicEndpoint.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/BasicEndpoint.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/BasicEndpoint.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -42,6 +42,7 @@
    private String shortName;
    private String urlPattern;
    private String targetBean;
+   private String address;
    private EndpointState state;
    private RequestHandler requestHandler;
    private InvocationHandler invocationHandler;
@@ -135,6 +136,16 @@
       this.urlPattern = urlPattern;
    }
 
+   public String getAddress()
+   {
+      return address;
+   }
+
+   public void setAddress(String address)
+   {
+      this.address = address;
+   }
+
    public EndpointState getState()
    {
       return state;

Modified: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -90,6 +90,12 @@
    /** Set the URL pattern for this endpoint */
    void setURLPattern(String urlPattern);
 
+   /** Get endpoint address */
+   String getAddress();
+
+   /** Set endpoint address */
+   void setAddress(String address);
+   
    /** Set the request handler for this endpoint */
    void setRequestHandler(RequestHandler handler);
 

Added: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/EndpointAddressDeploymentAspect.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/EndpointAddressDeploymentAspect.java	                        (rev 0)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/deployment/EndpointAddressDeploymentAspect.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -0,0 +1,53 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.wsf.spi.deployment;
+
+//$Id: URLPatternDeployer.java 3576 2007-06-14 09:23:52Z thomas.diesler at jboss.com $
+
+/**
+ * A deployer that assigns the endpoint address. 
+ *
+ * @author Thomas.Diesler at jboss.org
+ * @since 19-May-2007
+ */
+public class EndpointAddressDeploymentAspect extends DeploymentAspect
+{
+   @Override
+   public void create(Deployment dep)
+   {
+      String contextRoot = dep.getService().getContextRoot();
+      if (contextRoot == null)
+         throw new IllegalStateException("Cannot obtain context root");
+
+      for (Endpoint ep : dep.getService().getEndpoints())
+      {
+         String urlPattern = ep.getURLPattern();
+         if (urlPattern == null)
+            throw new IllegalStateException("Cannot obtain url pattern");
+
+         if (urlPattern.endsWith("/*"))
+            urlPattern = urlPattern.substring(0, urlPattern.length() - 2);
+
+         ep.setAddress(contextRoot + urlPattern);
+      }
+   }
+}
\ No newline at end of file

Modified: trunk/integration/xfire/.classpath
===================================================================
--- trunk/integration/xfire/.classpath	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/.classpath	2007-07-19 18:03:54 UTC (rev 3956)
@@ -8,14 +8,16 @@
 	<classpathentry kind="lib" path="thirdparty/servlet-api.jar"/>
 	<classpathentry combineaccessrules="false" kind="src" path="/integration-spi"/>
 	<classpathentry kind="lib" path="/integration-spi/thirdparty/dom4j.jar"/>
-	<classpathentry kind="lib" path="thirdparty/xfire-all.jar" sourcepath="thirdparty/xfire-distribution-sources.jar"/>
 	<classpathentry kind="lib" path="thirdparty/jaxws-api.jar"/>
-	<classpathentry kind="lib" path="thirdparty/xfire-jsr181-api.jar"/>
 	<classpathentry kind="lib" path="/integration-spi/thirdparty/jboss-common-core.jar"/>
-	<classpathentry kind="lib" path="thirdparty/spring.jar"/>
-	<classpathentry kind="lib" path="thirdparty/xbean.jar"/>
-	<classpathentry kind="lib" path="thirdparty/xbean-spring.jar"/>
 	<classpathentry combineaccessrules="false" kind="src" path="/integration-jboss50"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.USER_LIBRARY/jboss-5.0.x"/>
+	<classpathentry kind="lib" path="thirdparty/cxf-incubator.jar" sourcepath="/home/tdiesler/Download/java/apache/cxf/apache-cxf-2.0-incubator-src.zip"/>
+	<classpathentry kind="lib" path="thirdparty/geronimo-ws-metadata.jar"/>
+	<classpathentry kind="lib" path="thirdparty/saaj-api.jar"/>
+	<classpathentry kind="lib" path="thirdparty/spring-context.jar"/>
+	<classpathentry kind="lib" path="thirdparty/spring-beans.jar"/>
+	<classpathentry kind="lib" path="thirdparty/spring-core.jar"/>
+	<classpathentry kind="lib" path="thirdparty/spring-web.jar"/>
 	<classpathentry kind="output" path="output/eclipse"/>
 </classpath>

Modified: trunk/integration/xfire/ant-import/build-testsuite.xml
===================================================================
--- trunk/integration/xfire/ant-import/build-testsuite.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/ant-import/build-testsuite.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -25,45 +25,21 @@
   <!-- ================================================================== -->
   
   <target name="tests-init" depends="tests-classpath">
-
-    <!-- 
-      Cannot use XFire client
-      [JBWS-1654] - ServiceDelegate requires non portable method getPortClassMap
-    -->
-    <ant antfile="${int.sunri.dir}/build.xml" target="thirdparty" inheritall="false"/>
-
-    <path id="sunri.classpath">
-      <pathelement location="${int.sunri.dir}/thirdparty/FastInfoset.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/http.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jaxws-api.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jaxws-rt.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jaxws-tools.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jsr173_api.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jsr181-api.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/jsr250-api.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/resolver.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/saaj-api.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/saaj-impl.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/sjsxp.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/stax-ex.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/streambuffer.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/wstx.jar"/>
-      <pathelement location="${int.sunri.dir}/thirdparty/wsdl4j.jar"/>
-    </path>
     
-    <path id="xfire.classpath">
-      <pathelement location="${thirdparty.dir}/jaxws-api.jar"/>
-      <pathelement location="${thirdparty.dir}/jdom.jar"/>
-      <pathelement location="${thirdparty.dir}/saaj-api.jar"/>
-      <pathelement location="${thirdparty.dir}/saaj-impl.jar"/>
-      <pathelement location="${thirdparty.dir}/wsdl4j.jar"/>
-      <pathelement location="${thirdparty.dir}/xfire-all.jar"/>
-      <pathelement location="${thirdparty.dir}/xfire-jsr181-api.jar"/>
-    </path>
-    
     <path id="ws.stack.classpath">
       <pathelement location="${spi.dir}/output/lib/jbossws-spi.jar"/>
-      <path refid="sunri.classpath"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/cxf-incubator.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/geronimo-javamail.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/geronimo-ws-metadata.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/jaxws-api.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/jdom.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/neethi.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/resolver.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/saaj-api.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/saaj-impl.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/wsdl4j.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/wstx.jar"/>
+      <pathelement location="${int.xfire.dir}/thirdparty/XmlSchema.jar"/>
     </path>
     
     <path id="tests.extra.classpath">

Modified: trunk/integration/xfire/ant-import/build-thirdparty.xml
===================================================================
--- trunk/integration/xfire/ant-import/build-thirdparty.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/ant-import/build-thirdparty.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -42,6 +42,19 @@
     description="Gets the thirdparty libraries">
 
     <mkdir dir="${thirdparty.dir}"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/cxf-incubator.jar" dest="${thirdparty.dir}/cxf-incubator.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/geronimo-javamail.jar" dest="${thirdparty.dir}/geronimo-javamail.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/geronimo-ws-metadata.jar" dest="${thirdparty.dir}/geronimo-ws-metadata.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/jaxws-api.jar" dest="${thirdparty.dir}/jaxws-api.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/neethi.jar" dest="${thirdparty.dir}/neethi.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/saaj-api.jar" dest="${thirdparty.dir}/saaj-api.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/saaj-impl.jar" dest="${thirdparty.dir}/saaj-impl.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/spring-beans.jar" dest="${thirdparty.dir}/spring-beans.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/spring-context.jar" dest="${thirdparty.dir}/spring-context.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/spring-core.jar" dest="${thirdparty.dir}/spring-core.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/spring-web.jar" dest="${thirdparty.dir}/spring-web.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-cxf/${apache-cxf}/lib/XmlSchema.jar" dest="${thirdparty.dir}/XmlSchema.jar" usetimestamp="true" verbose="true"/>
+    <get src="${jboss.repository}/apache-xml-commons/${apache-xml-commons}/lib/resolver.jar" dest="${thirdparty.dir}/resolver.jar" usetimestamp="true" verbose="true"/>
     <get src="${jboss.repository}/ibm-wsdl4j/${ibm-wsdl4j}/lib/wsdl4j.jar" dest="${thirdparty.dir}/wsdl4j.jar" usetimestamp="true" verbose="true"/>
     <get src="${jboss.repository}/ibm-wsdl4j/${ibm-wsdl4j}/lib/wsdl4j-src.jar" dest="${thirdparty.dir}/wsdl4j-src.jar" usetimestamp="true" verbose="true"/>
     <get src="${jboss.repository}/jboss/jaxr/${jboss-jaxr}/lib/juddi-service.sar" dest="${thirdparty.dir}/juddi-service.sar" usetimestamp="true" verbose="true"/>
@@ -51,42 +64,29 @@
     <get src="${jboss.repository}/sun-jaxb/${sun-jaxb}/lib/jaxb-xjc.jar" dest="${thirdparty.dir}/jaxb-xjc.jar" usetimestamp="true" verbose="true"/>
     <get src="${jboss.repository}/sun-servlet/${sun-servlet}/lib/servlet-api.jar" dest="${thirdparty.dir}/servlet-api.jar" usetimestamp="true" verbose="true"/>
     <get src="${jboss.repository}/woodstox/${woodstox}/lib/wstx.jar" dest="${thirdparty.dir}/wstx.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/jaxws-api.jar" dest="${thirdparty.dir}/jaxws-api.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/jdom.jar" dest="${thirdparty.dir}/jdom.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/saaj-api.jar" dest="${thirdparty.dir}/saaj-api.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/saaj-impl.jar" dest="${thirdparty.dir}/saaj-impl.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/spring.jar" dest="${thirdparty.dir}/spring.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/xbean.jar" dest="${thirdparty.dir}/xbean.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/xbean-spring.jar" dest="${thirdparty.dir}/xbean-spring.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/xfire-all.jar" dest="${thirdparty.dir}/xfire-all.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/xfire-distribution-sources.jar" dest="${thirdparty.dir}/xfire-distribution-sources.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/xfire/${xfire}/lib/xfire-jsr181-api.jar" dest="${thirdparty.dir}/xfire-jsr181-api.jar" usetimestamp="true" verbose="true"/>
-    <get src="${jboss.repository}/ibm-wsdl4j/${ibm-wsdl4j}/lib/wsdl4j.jar" dest="${thirdparty.dir}/wsdl4j.jar" usetimestamp="true" verbose="true"/>
     
     <checksum file="${int.xfire.dir}/version.properties" fileext=".md5"/>
   </target>
   
   <target name="thirdparty-classpath" depends="thirdparty-init">
     
-    <!-- The compile classpath for jboss50 integration -->
     <path id="xfire.integration.classpath">
       <pathelement location="${spi.dir}/output/lib/jbossws-spi.jar"/>
       <pathelement location="${spi.dir}/thirdparty/dom4j.jar"/>
       <pathelement location="${spi.dir}/thirdparty/jboss-common-core.jar"/>
       <pathelement location="${spi.dir}/thirdparty/jboss-logging-spi.jar"/>
+      <pathelement location="${thirdparty.dir}/cxf-incubator.jar"/>
+      <pathelement location="${thirdparty.dir}/geronimo-ws-metadata.jar"/>
+      <pathelement location="${thirdparty.dir}/jaxb-api.jar"/>
       <pathelement location="${thirdparty.dir}/jaxws-api.jar"/>
+      <pathelement location="${thirdparty.dir}/saaj-api.jar"/>
+      <pathelement location="${thirdparty.dir}/saaj-impl.jar"/>
       <pathelement location="${thirdparty.dir}/servlet-api.jar"/>
-      <pathelement location="${thirdparty.dir}/spring.jar"/>
-      <pathelement location="${thirdparty.dir}/xfire-all.jar"/>
-      <pathelement location="${thirdparty.dir}/xfire-jsr181-api.jar"/>
+      <pathelement location="${thirdparty.dir}/spring-beans.jar"/>
+      <pathelement location="${thirdparty.dir}/spring-context.jar"/>
+      <pathelement location="${thirdparty.dir}/spring-core.jar"/>
     </path>
     
-    <path id="xfire50.integration.classpath">
-      <path refid="xfire.integration.classpath"/>
-      <pathelement location="${int.jboss50.dir}/output/lib/jbossws-jboss50.jar"/>
-      <pathelement location="${jboss50.server.lib}/jboss.jar"/>
-    </path>
-    
   </target>
 
 </project>

Modified: trunk/integration/xfire/ant-import/macros-deploy-xfire.xml
===================================================================
--- trunk/integration/xfire/ant-import/macros-deploy-xfire.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/ant-import/macros-deploy-xfire.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -57,7 +57,6 @@
 				<fileset dir="@{thirdpartylibs}">
 					<include name="jaxws-api.jar"/>
 					<include name="saaj-api.jar"/>
-					<include name="xfire-jsr181-api.jar"/>
 				</fileset>
       </copy>
       
@@ -121,6 +120,7 @@
           <include name="jaxb-api.jar"/>
           <include name="jaxb-impl.jar"/>
           <include name="jaxb-xjc.jar"/>
+          <include name="resolver.jar"/>
         </fileset>
       </copy>
       
@@ -156,6 +156,7 @@
         <fileset dir="${jboss42.home}/client">
           <include name="jbossws-spi.jar"/>
           <include name="jbossws-jboss42.jar"/>
+          <include name="resolver.jar"/>
         </fileset>
         
   			<!--SERVER JARS -->

Modified: trunk/integration/xfire/build.xml
===================================================================
--- trunk/integration/xfire/build.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/build.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -153,16 +153,15 @@
         <include name="jaxrpc-api.jar"/>
       </fileset>
       <fileset dir="${thirdparty.dir}">
+        <include name="cxf-incubator.jar"/>
         <include name="jaxws-api.jar"/>
         <include name="jdom.jar"/>
         <include name="wsdl4j.jar"/>
         <include name="saaj-api.jar"/>
         <include name="saaj-impl.jar"/>
-        <include name="spring.jar"/>
+        <include name="spring-bean.jar"/>
+        <include name="spring-core.jar"/>
         <include name="xbean.jar"/>
-        <include name="xbean-spring.jar"/>
-        <include name="xfire-all.jar"/>
-        <include name="xfire-jsr181-api.jar"/>
       </fileset>
       <fileset dir="${xfire.output.lib.dir}">
         <include name="jbossws-xfire.jar"/>
@@ -205,20 +204,24 @@
         <include name="jbossws-xfire.jar"/>
       </fileset>
       <fileset dir="${thirdparty.dir}">
+        <include name="cxf-incubator.jar"/>
+        <include name="geronimo-ws-metadata.jar"/>
         <include name="jaxb-api.jar"/>
         <include name="jaxb-impl.jar"/>
         <include name="jaxws-api.jar"/>
         <include name="jdom.jar"/>
+        <include name="neethi.jar"/>
         <include name="wsdl4j.jar"/>
+        <include name="resolver.jar"/>
         <include name="saaj-api.jar"/>
         <include name="saaj-impl.jar"/>
-        <include name="spring.jar"/>
+        <include name="spring-beans.jar"/>
+        <include name="spring-context.jar"/>
+        <include name="spring-core.jar"/>
         <include name="stax-api.jar"/>
         <include name="wstx.jar"/>
         <include name="xbean.jar"/>
-        <include name="xbean-spring.jar"/>
-        <include name="xfire-all.jar"/>
-        <include name="xfire-jsr181-api.jar"/>
+        <include name="XmlSchema.jar"/>
       </fileset>
       <fileset dir="${xfire.output.lib.dir}/jbossws-xfire42">
         <include name="jbossws.beans/**"/>

Copied: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/CXFServletExt.java (from rev 3949, trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireConfigurableServletExt.java)
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/CXFServletExt.java	                        (rev 0)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/CXFServletExt.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -0,0 +1,160 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.wsf.stack.xfire;
+
+//$Id$
+
+import java.io.IOException;
+import java.io.InputStream;
+import java.net.URL;
+
+import javax.management.ObjectName;
+import javax.servlet.ServletConfig;
+import javax.servlet.ServletException;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
+import javax.xml.ws.WebServiceException;
+
+import org.apache.cxf.transport.DestinationFactory;
+import org.apache.cxf.transport.servlet.CXFServlet;
+import org.apache.cxf.transport.servlet.ServletController;
+import org.apache.cxf.transport.servlet.ServletTransportFactory;
+import org.jboss.logging.Logger;
+import org.jboss.wsf.spi.deployment.Endpoint;
+import org.jboss.wsf.spi.deployment.EndpointAssociation;
+import org.jboss.wsf.spi.invocation.RequestHandler;
+import org.jboss.wsf.spi.management.EndpointRegistry;
+import org.jboss.wsf.spi.management.EndpointRegistryFactory;
+import org.jboss.wsf.spi.utils.ObjectNameFactory;
+import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
+import org.springframework.context.ApplicationContext;
+import org.springframework.context.support.GenericApplicationContext;
+import org.springframework.core.io.InputStreamResource;
+
+/**
+ * An extension to the CXF servlet
+ * 
+ * @author Thomas.Diesler at jboss.org
+ * @since 21-Apr-2007
+ */
+public class CXFServletExt extends CXFServlet
+{
+   public static final String PARAM_CXF_BEANS_URL = "jbossws.cxf.beans.url";
+
+   private static Logger log = Logger.getLogger(CXFServletExt.class);
+
+   protected Endpoint endpoint;
+   protected EndpointRegistry epRegistry;
+   protected GenericApplicationContext childCtx;
+
+   public void init(ServletConfig servletConfig) throws ServletException
+   {
+      super.init(servletConfig);
+
+      // Init the Endpoint
+      epRegistry = EndpointRegistryFactory.getEndpointRegistry();
+      String contextPath = servletConfig.getServletContext().getContextPath();
+      endpoint = initServiceEndpoint(contextPath);
+      endpoint.addAttachment(ServletController.class, getController());
+   }
+
+   public ServletController createServletController()
+   {
+      ServletTransportFactory stf = (ServletTransportFactory)createServletTransportFactory();
+      return new ServletControllerExt(stf, this);
+   }
+
+   protected void loadAdditionalConfig(ApplicationContext ctx, ServletConfig servletConfig) throws ServletException
+   {
+      String location = servletConfig.getServletContext().getInitParameter(PARAM_CXF_BEANS_URL);
+
+      InputStream is;
+      try
+      {
+         is = new URL(location).openStream();
+      }
+      catch (IOException e)
+      {
+         throw new ServletException(e);
+      }
+
+      if (is != null)
+      {
+         childCtx = new GenericApplicationContext(ctx);
+         XmlBeanDefinitionReader reader = new XmlBeanDefinitionReader(childCtx);
+         reader.setValidationMode(XmlBeanDefinitionReader.VALIDATION_XSD);
+         reader.loadBeanDefinitions(new InputStreamResource(is, location));
+
+         childCtx.refresh();
+      }
+   }
+
+   public void service(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException
+   {
+      try
+      {
+         EndpointAssociation.setEndpoint(endpoint);
+         RequestHandler requestHandler = (RequestHandler)endpoint.getRequestHandler();
+         requestHandler.handleHttpRequest(endpoint, req, res, getServletContext());
+      }
+      finally
+      {
+         EndpointAssociation.removeEndpoint();
+      }
+   }
+
+   public void destroy()
+   {
+      if (childCtx != null)
+         childCtx.destroy();
+   }
+
+   /** Initialize the service endpoint
+    */
+   protected Endpoint initServiceEndpoint(String contextPath)
+   {
+      if (contextPath.startsWith("/"))
+         contextPath = contextPath.substring(1);
+
+      Endpoint endpoint = null;
+      String servletName = getServletName();
+      for (ObjectName sepId : epRegistry.getEndpoints())
+      {
+         String propContext = sepId.getKeyProperty(Endpoint.SEPID_PROPERTY_CONTEXT);
+         String propEndpoint = sepId.getKeyProperty(Endpoint.SEPID_PROPERTY_ENDPOINT);
+         if (servletName.equals(propEndpoint) && contextPath.equals(propContext))
+         {
+            endpoint = epRegistry.getEndpoint(sepId);
+            break;
+         }
+      }
+
+      if (endpoint == null)
+      {
+         ObjectName oname = ObjectNameFactory.create(Endpoint.SEPID_DOMAIN + ":" + Endpoint.SEPID_PROPERTY_CONTEXT + "=" + contextPath + ","
+               + Endpoint.SEPID_PROPERTY_ENDPOINT + "=" + servletName);
+         throw new WebServiceException("Cannot obtain endpoint for: " + oname);
+      }
+
+      return endpoint;
+   }
+}

Added: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/DescriptorDeploymentAspect.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/DescriptorDeploymentAspect.java	                        (rev 0)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/DescriptorDeploymentAspect.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -0,0 +1,122 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.wsf.stack.xfire;
+
+//$Id: XFireServicesDeployer.java 3802 2007-07-05 16:44:32Z thomas.diesler at jboss.com $
+
+import java.util.HashMap;
+import java.util.Map;
+
+import org.jboss.logging.Logger;
+import org.jboss.wsf.spi.deployment.Deployment;
+import org.jboss.wsf.spi.deployment.DeploymentAspect;
+import org.jboss.wsf.spi.deployment.Endpoint;
+import org.jboss.wsf.spi.deployment.WebAppDesciptorModifier;
+import org.jboss.wsf.spi.deployment.Deployment.DeploymentType;
+import org.jboss.wsf.stack.xfire.metadata.services.DDBean;
+import org.jboss.wsf.stack.xfire.metadata.services.DDBeans;
+import org.jboss.wsf.stack.xfire.metadata.services.DDEndpoint;
+
+/**
+ * A deployer that generates cxf.xml 
+ *
+ * @author Thomas.Diesler at jboss.org
+ * @since 10-May-2007
+ */
+public class DescriptorDeploymentAspect extends DeploymentAspect
+{
+   // provide logging
+   private static final Logger log = Logger.getLogger(DescriptorDeploymentAspect.class);
+
+   private String invokerEJB3;
+   private String invokerJSE;
+
+   public void setInvokerEJB3(String invokerEJB3)
+   {
+      this.invokerEJB3 = invokerEJB3;
+   }
+
+   public void setInvokerJSE(String invokerJSE)
+   {
+      this.invokerJSE = invokerJSE;
+   }
+
+   @Override
+   public void create(Deployment dep)
+   {
+      DeploymentType depType = dep.getType();
+      if (depType != DeploymentType.JAXWS_EJB3 && depType != DeploymentType.JAXWS_JSE)
+         throw new IllegalStateException("Unsupported deployment type: " + depType);
+
+      DDBeans dd = new DDBeans();
+      for (Endpoint ep : dep.getService().getEndpoints())
+      {
+         String id = ep.getShortName();
+         String address = ep.getAddress();
+         String implementor = ep.getTargetBeanName();
+
+         DDEndpoint ddep = new DDEndpoint(id, address, implementor);
+
+         if (depType == DeploymentType.JAXWS_EJB3 && invokerEJB3 != null)
+            ddep.setInvoker("InvokerBeanEJB3");
+
+         if (depType == DeploymentType.JAXWS_JSE && invokerJSE != null)
+            ddep.setInvoker("InvokerBeanJSE");
+
+         log.info("Add " + ddep);
+         dd.addEndpoint(ddep);
+      }
+      
+      if (depType == DeploymentType.JAXWS_EJB3 && invokerEJB3 != null)
+      {
+         DDBean bean = new DDBean("InvokerBeanEJB3", invokerEJB3);
+         dd.addBean(bean);
+      }
+
+      if (depType == DeploymentType.JAXWS_JSE && invokerJSE != null)
+      {
+         DDBean bean = new DDBean("InvokerBeanJSE", invokerJSE);
+         dd.addBean(bean);
+      }
+
+      dep.getContext().addAttachment(DDBeans.class, dd);
+
+      String propKey = WebAppDesciptorModifier.CONTEXT_PARAMETER_MAP;
+      Map<String, String> contextParams = (Map<String, String>)dep.getContext().getProperty(propKey);
+      if (contextParams == null)
+      {
+         contextParams = new HashMap<String, String>();
+         dep.getContext().setProperty(propKey, contextParams);
+      }
+      contextParams.put(CXFServletExt.PARAM_CXF_BEANS_URL, dd.createFileURL().toExternalForm());
+   }
+
+   @Override
+   public void destroy(Deployment dep)
+   {
+      DDBeans dd = dep.getContext().getAttachment(DDBeans.class);
+      if (dd != null)
+      {
+         dd.destroyFileURL();
+      }
+   }
+}
\ No newline at end of file

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerEJB3.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerEJB3.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerEJB3.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -23,17 +23,9 @@
 
 //$Id$
 
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
+import org.apache.cxf.message.Exchange;
+import org.apache.cxf.service.invoker.Invoker;
 
-import org.codehaus.xfire.MessageContext;
-import org.codehaus.xfire.fault.XFireFault;
-import org.codehaus.xfire.service.invoker.Invoker;
-import org.jboss.wsf.spi.deployment.Endpoint;
-import org.jboss.wsf.spi.deployment.EndpointAssociation;
-import org.jboss.wsf.spi.invocation.Invocation;
-import org.jboss.wsf.spi.invocation.InvocationHandler;
-
 /**
  * An XFire invoker for EJB3
  * 
@@ -42,35 +34,43 @@
  */
 public class InvokerEJB3 implements Invoker
 {
-   public Object invoke(Method m, Object[] params, MessageContext context) throws XFireFault
+   public Object invoke(Exchange arg0, Object arg1)
    {
-      Endpoint ep = EndpointAssociation.getEndpoint();
-      InvocationHandler invHandler = ep.getInvocationHandler();
+      // TODO Auto-generated method stub
+      return null;
+   }
+   
+   /*
+    public Object invoke(Method m, Object[] params, MessageContext context) 
+    {
+    Endpoint ep = EndpointAssociation.getEndpoint();
+    InvocationHandler invHandler = ep.getInvocationHandler();
 
-      Invocation inv = invHandler.createInvocation();
-      inv.getInvocationContext().addAttachment(MessageContext.class, context);
-      inv.setJavaMethod(m);
-      inv.setArgs(params);
+    Invocation inv = invHandler.createInvocation();
+    inv.getInvocationContext().addAttachment(MessageContext.class, context);
+    inv.setJavaMethod(m);
+    inv.setArgs(params);
 
-      Object retObj = null;
-      try
-      {
-         invHandler.invoke(ep, inv);
-         retObj = inv.getReturnValue();
-      }
-      catch (Exception ex)
-      {
-         handleException(ex);
-      }
+    Object retObj = null;
+    try
+    {
+    invHandler.invoke(ep, inv);
+    retObj = inv.getReturnValue();
+    }
+    catch (Exception ex)
+    {
+    handleException(ex);
+    }
 
-      return retObj;
-   }
+    return retObj;
+    }
 
-   private void handleException(Exception ex) throws XFireFault
-   {
-      if (ex instanceof InvocationTargetException)
-         throw XFireFault.createFault(((InvocationTargetException)ex).getTargetException());
+    private void handleException(Exception ex) throws XFireFault
+    {
+    if (ex instanceof InvocationTargetException)
+    throw XFireFault.createFault(((InvocationTargetException)ex).getTargetException());
 
-      throw XFireFault.createFault(ex);
-   }
+    throw XFireFault.createFault(ex);
+    }
+    */
 }
\ No newline at end of file

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerJSE.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/RequestHandlerImpl.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/RequestHandlerImpl.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -32,7 +32,7 @@
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.codehaus.xfire.transport.http.XFireServletController;
+import org.apache.cxf.transport.servlet.ServletController;
 import org.jboss.logging.Logger;
 import org.jboss.util.NotImplementedException;
 import org.jboss.wsf.spi.deployment.Endpoint;
@@ -52,11 +52,11 @@
 
    public void handleHttpRequest(Endpoint ep, HttpServletRequest req, HttpServletResponse res, ServletContext context) throws ServletException, IOException
    {
-      XFireServletController controller = ep.getAttachment(XFireServletController.class);
+      ServletController controller = ep.getAttachment(ServletController.class);
       if (controller == null)
-         throw new IllegalStateException("Cannot obtain XFire servlet controller");
+         throw new IllegalStateException("Cannot obtain servlet controller");
 
-      controller.doService(req, res);
+      controller.invoke(req, res);
    }
 
    public void handleRequest(Endpoint endpoint, InputStream inStream, OutputStream outStream, InvocationContext context)

Copied: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/ServletControllerExt.java (from rev 3949, trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServletControllerExt.java)
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/ServletControllerExt.java	                        (rev 0)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/ServletControllerExt.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -0,0 +1,111 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.wsf.stack.xfire;
+
+//$Id$
+
+import java.io.IOException;
+import java.io.OutputStream;
+
+import javax.servlet.ServletException;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
+
+import org.apache.cxf.Bus;
+import org.apache.cxf.service.model.EndpointInfo;
+import org.apache.cxf.transport.servlet.CXFServlet;
+import org.apache.cxf.transport.servlet.ServletController;
+import org.apache.cxf.transport.servlet.ServletDestination;
+import org.apache.cxf.transport.servlet.ServletTransportFactory;
+import org.apache.cxf.transports.http.QueryHandler;
+import org.apache.cxf.transports.http.QueryHandlerRegistry;
+import org.jboss.logging.Logger;
+
+/**
+ * An extension to the CXF servlet controller
+ * 
+ * @author Thomas.Diesler at jboss.org
+ * @since 21-Apr-2007
+ */
+public class ServletControllerExt extends ServletController
+{
+   private static Logger log = Logger.getLogger(ServletControllerExt.class);
+
+   private ServletTransportFactory transport;
+   private CXFServlet cxfServlet;
+
+   public ServletControllerExt(ServletTransportFactory transport, CXFServlet servlet)
+   {
+      super(transport, servlet);
+      this.transport = transport;
+      this.cxfServlet = servlet;
+   }
+
+   public void invoke(HttpServletRequest req, HttpServletResponse res) throws ServletException
+   {
+      try
+      {
+         // JBossWS always uses the request URI
+         EndpointInfo ei = new EndpointInfo();
+         String address = req.getRequestURI();
+
+         ei.setAddress(address);
+         ServletDestination dest = (ServletDestination)transport.getDestinationForPath(ei.getAddress());
+         if (dest == null)
+            throw new ServletException("Cannot obtain destination for: " + address);
+
+         ei = dest.getEndpointInfo();
+         Bus bus = cxfServlet.getBus();
+         if (null != req.getQueryString() && req.getQueryString().length() > 0 && bus.getExtension(QueryHandlerRegistry.class) != null)
+         {
+            String ctxUri = address; //req.getPathInfo();
+            String baseUri = req.getRequestURL().toString() + "?" + req.getQueryString();
+
+            for (QueryHandler qh : bus.getExtension(QueryHandlerRegistry.class).getHandlers())
+            {
+               if (qh.isRecognizedQuery(baseUri, ctxUri, ei))
+               {
+
+                  res.setContentType(qh.getResponseContentType(baseUri, ctxUri));
+                  OutputStream out = res.getOutputStream();
+                  try
+                  {
+                     qh.writeResponse(baseUri, ctxUri, ei, out);
+                     out.flush();
+                     return;
+                  }
+                  catch (Exception e)
+                  {
+                     throw new ServletException(e);
+                  }
+               }
+            }
+         }
+
+         invokeDestination(req, res, dest);
+      }
+      catch (IOException e)
+      {
+         throw new ServletException(e);
+      }
+   }
+}

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/WebAppDesciptorModifierImpl.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/WebAppDesciptorModifierImpl.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/WebAppDesciptorModifierImpl.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -64,7 +64,7 @@
          throw new IllegalStateException("Cannot obtain sun-jaxws meta data");
 
       Element contextParam = root.addElement("context-param");
-      contextParam.addElement("param-name").addText(XFireConfigurableServletExt.PARAM_XFIRE_SERVICES_URL);
+      contextParam.addElement("param-name").addText(CXFServletExt.PARAM_CXF_BEANS_URL);
       contextParam.addElement("param-value").addText(ddbeans.createFileURL().toExternalForm());
 
       for (Iterator it = root.elementIterator("servlet"); it.hasNext();)

Deleted: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireConfigurableServletExt.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireConfigurableServletExt.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireConfigurableServletExt.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -1,184 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.xfire;
-
-//$Id$
-
-import java.io.IOException;
-import java.net.URL;
-
-import javax.management.ObjectName;
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.xml.ws.WebServiceException;
-
-import org.codehaus.xfire.XFire;
-import org.codehaus.xfire.XFireException;
-import org.codehaus.xfire.spring.XFireConfigLoader;
-import org.codehaus.xfire.transport.http.XFireConfigurableServlet;
-import org.codehaus.xfire.transport.http.XFireServletController;
-import org.jboss.logging.Logger;
-import org.jboss.wsf.spi.deployment.Endpoint;
-import org.jboss.wsf.spi.deployment.EndpointAssociation;
-import org.jboss.wsf.spi.invocation.RequestHandler;
-import org.jboss.wsf.spi.management.EndpointRegistry;
-import org.jboss.wsf.spi.management.EndpointRegistryFactory;
-import org.jboss.wsf.spi.utils.ObjectNameFactory;
-import org.springframework.context.ApplicationContext;
-import org.springframework.web.context.WebApplicationContext;
-import org.springframework.web.context.support.GenericWebApplicationContext;
-
-/**
- * An extension to the XFire servlet
- * 
- * @author Thomas.Diesler at jboss.org
- * @since 21-Apr-2007
- */
-public class XFireConfigurableServletExt extends XFireConfigurableServlet
-{
-   public static final String PARAM_XFIRE_SERVICES_URL = "jbossws.xfire.services.url";
-
-   private final static String CONFIG_FILE = "/WEB-INF/classes/META-INF/xfire/services.xml";
-
-   private static Logger log = Logger.getLogger(XFireConfigurableServletExt.class);
-   
-   protected Endpoint endpoint;
-   protected EndpointRegistry epRegistry;
-
-   public void init(ServletConfig servletConfig) throws ServletException
-   {
-      super.init(servletConfig);
-
-      // Init the Endpoint
-      epRegistry = EndpointRegistryFactory.getEndpointRegistry();
-      String contextPath = servletConfig.getServletContext().getContextPath();
-      endpoint = initServiceEndpoint(contextPath);
-      endpoint.addAttachment(XFireServletController.class, controller);
-   }
-
-   public XFire createXFire() throws ServletException
-   {
-      XFire xfire;
-      try
-      {
-         // #1 Load services.xml from default location
-         ServletContext context = getServletContext();
-         URL servicesURL = context.getResource(CONFIG_FILE);
-
-         // #1 Load services.xml from init parameter
-         if (servicesURL == null)
-         {
-            String paramValue = context.getInitParameter(PARAM_XFIRE_SERVICES_URL);
-            if (paramValue != null)
-               servicesURL = new URL(paramValue);
-         }
-
-         xfire = loadConfig(servicesURL.getFile());
-      }
-      catch (Exception e)
-      {
-         throw new ServletException(e);
-      }
-
-      return xfire;
-   }
-
-   public XFire loadConfig(String configPath) throws XFireException
-   {
-       XFireConfigLoader loader = new XFireConfigLoader();
-       //loader.setBasedir(getWebappBase());
-       //log.debug("Loading configuration files relative to " + loader.getBasedir().getAbsolutePath());
-
-       ServletContext servletCtx = getServletContext();
-       ApplicationContext parent = (ApplicationContext) servletCtx.getAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE);
-
-       if (parent == null)
-       {
-           GenericWebApplicationContext webCtx = new GenericWebApplicationContextX();
-           webCtx.setServletContext(getServletContext());
-           webCtx.refresh();
-           parent = webCtx;
-       }
-       
-       ApplicationContext newCtx = loader.loadContext(configPath, parent);
-       if(servletCtx.getAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE) == null)
-       {
-            servletCtx.setAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE, newCtx);
-       }
-
-       XFire xfire = (XFire) newCtx.getBean("xfire");
-       xfire.setProperty(XFire.XFIRE_HOME, getWebappBase().getAbsolutePath());
-       return xfire;
-   }
-   
-   public XFireServletController createController() throws ServletException
-   {
-      return new XFireServletControllerExt(xfire, getServletContext());
-   }
-
-   public void service(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException
-   {
-      try
-      {
-         EndpointAssociation.setEndpoint(endpoint);
-         RequestHandler requestHandler = (RequestHandler)endpoint.getRequestHandler();
-         requestHandler.handleHttpRequest(endpoint, req, res, getServletContext());
-      }
-      finally
-      {
-         EndpointAssociation.removeEndpoint();
-      }
-   }
-
-   /** Initialize the service endpoint
-    */
-   protected Endpoint initServiceEndpoint(String contextPath)
-   {
-      if (contextPath.startsWith("/"))
-         contextPath = contextPath.substring(1);
-
-      Endpoint endpoint = null;
-      String servletName = getServletName();
-      for (ObjectName sepId : epRegistry.getEndpoints())
-      {
-         String propContext = sepId.getKeyProperty(Endpoint.SEPID_PROPERTY_CONTEXT);
-         String propEndpoint = sepId.getKeyProperty(Endpoint.SEPID_PROPERTY_ENDPOINT);
-         if (servletName.equals(propEndpoint) && contextPath.equals(propContext))
-         {
-            endpoint = epRegistry.getEndpoint(sepId);
-            break;
-         }
-      }
-
-      if (endpoint == null)
-      {
-         ObjectName oname = ObjectNameFactory.create(Endpoint.SEPID_DOMAIN + ":" + Endpoint.SEPID_PROPERTY_CONTEXT + "=" + contextPath + ","
-               + Endpoint.SEPID_PROPERTY_ENDPOINT + "=" + servletName);
-         throw new WebServiceException("Cannot obtain endpoint for: " + oname);
-      }
-      
-      return endpoint;
-   }
-}

Deleted: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServicesDeploymentAspect.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServicesDeploymentAspect.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServicesDeploymentAspect.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -1,124 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.xfire;
-
-//$Id: XFireServicesDeployer.java 3802 2007-07-05 16:44:32Z thomas.diesler at jboss.com $
-
-import java.util.HashMap;
-import java.util.Map;
-
-import org.jboss.logging.Logger;
-import org.jboss.wsf.spi.deployment.Deployment;
-import org.jboss.wsf.spi.deployment.DeploymentAspect;
-import org.jboss.wsf.spi.deployment.Endpoint;
-import org.jboss.wsf.spi.deployment.WebAppDesciptorModifier;
-import org.jboss.wsf.spi.deployment.Deployment.DeploymentType;
-import org.jboss.wsf.stack.xfire.metadata.services.DDBean;
-import org.jboss.wsf.stack.xfire.metadata.services.DDBeans;
-import org.jboss.wsf.stack.xfire.metadata.services.DDService;
-
-/**
- * A deployer that generates xfire services.xml 
- *
- * @author Thomas.Diesler at jboss.org
- * @since 10-May-2007
- */
-public class XFireServicesDeploymentAspect extends DeploymentAspect
-{
-   // provide logging
-   private static final Logger log = Logger.getLogger(XFireServicesDeploymentAspect.class);
-   
-   private String serviceFactory;
-   private String invokerEJB3;
-   private String invokerJSE;
-
-   public void setServiceFactory(String serviceFactory)
-   {
-      this.serviceFactory = serviceFactory;
-   }
-
-   public void setInvokerEJB3(String invokerEJB3)
-   {
-      this.invokerEJB3 = invokerEJB3;
-   }
-
-   public void setInvokerJSE(String invokerJSE)
-   {
-      this.invokerJSE = invokerJSE;
-   }
-
-   @Override
-   public void create(Deployment dep)
-   {
-      DeploymentType depType = dep.getType();
-      if (depType != DeploymentType.JAXWS_EJB3 && depType != DeploymentType.JAXWS_JSE)
-         throw new IllegalStateException("Unsupported deployment type: " + depType);
-      
-      DDBeans dd = new DDBeans();
-      for (Endpoint ep : dep.getService().getEndpoints())
-      {
-         String epName = ep.getShortName();
-         String targetBean = ep.getTargetBeanName();
-
-         DDService ddser = new DDService(epName, targetBean);
-         ddser.setServiceFactory(serviceFactory);
-         
-         if (depType == DeploymentType.JAXWS_EJB3 && invokerEJB3 != null)
-         {
-            String beanName = "InvokerBeanEJB3";
-            dd.addBean(new DDBean(beanName, invokerEJB3));
-            ddser.setInvoker("#" + beanName);
-         }
-         
-         if (depType == DeploymentType.JAXWS_JSE && invokerJSE != null)
-         {
-            String beanName = "InvokerBeanJSE";
-            dd.addBean(new DDBean(beanName, invokerJSE));
-            ddser.setInvoker("#" + beanName);
-         }
-
-         log.info("Add " + ddser);
-         dd.addService(ddser);
-      }
-      dep.getContext().addAttachment(DDBeans.class, dd);
-      
-      String propKey = WebAppDesciptorModifier.CONTEXT_PARAMETER_MAP;
-      Map<String, String> contextParams = (Map<String, String>)dep.getContext().getProperty(propKey);
-      if (contextParams == null)
-      {
-         contextParams = new HashMap<String, String>();
-         dep.getContext().setProperty(propKey, contextParams);
-      }
-      contextParams.put(XFireConfigurableServletExt.PARAM_XFIRE_SERVICES_URL, dd.createFileURL().toExternalForm());
-   }
-
-
-   @Override
-   public void destroy(Deployment dep)
-   {
-      DDBeans dd = dep.getContext().getAttachment(DDBeans.class);
-      if (dd != null)
-      {
-         dd.destroyFileURL();
-      }
-   }
-}
\ No newline at end of file

Deleted: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServletControllerExt.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServletControllerExt.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/XFireServletControllerExt.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -1,127 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.xfire;
-
-//$Id$
-
-import java.io.IOException;
-import java.net.URL;
-
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-
-import org.codehaus.xfire.XFire;
-import org.codehaus.xfire.service.Service;
-import org.codehaus.xfire.transport.http.XFireServletController;
-import org.jboss.logging.Logger;
-import org.jboss.ws.integration.UnifiedVirtualFile;
-import org.jboss.wsf.spi.deployment.Endpoint;
-import org.jboss.wsf.spi.deployment.EndpointAssociation;
-
-/**
- * An extension to the XFire servlet controller
- * 
- * @author Thomas.Diesler at jboss.org
- * @since 21-Apr-2007
- */
-public class XFireServletControllerExt extends XFireServletController
-{
-   private static Logger log = Logger.getLogger(XFireServletControllerExt.class);
-
-   public XFireServletControllerExt(XFire xfire, ServletContext servletContext)
-   {
-      super(xfire, servletContext);
-   }
-
-   protected String getService(HttpServletRequest request)
-   {
-      Endpoint ep = EndpointAssociation.getEndpoint();
-      String serviceName = ep.getShortName();
-      return serviceName;
-   }
-
-   protected void generateWSDL(HttpServletResponse response, String service) throws ServletException, IOException
-   {
-      Service userService = getXFire().getServiceRegistry().getService(service);
-      Object value = userService.getProperty(Service.DISABLE_WSDL_GENERATION);
-      boolean isWSDLDisabled = "true".equalsIgnoreCase((value != null ? value.toString() : null));
-      if (isWSDLDisabled)
-      {
-         log.warn("WSDL generation disabled for service :" + service);
-         response.sendError(404, "No wsdl is avaiable for this service");
-         return;
-      }
-
-      response.setStatus(200);
-      response.setContentType("text/xml");
-
-      ClassLoader ctxLoader = Thread.currentThread().getContextClassLoader();
-      try
-      {
-         Endpoint ep = EndpointAssociation.getEndpoint();
-         UnifiedVirtualFile rootFile = ep.getService().getDeployment().getRootFile();
-         Thread.currentThread().setContextClassLoader(new VirtualFileClassLoader(rootFile, ctxLoader));
-         getXFire().generateWSDL(service, response.getOutputStream());
-      }
-      finally
-      {
-         Thread.currentThread().setContextClassLoader(ctxLoader);
-      }
-   }
-   
-   /*
-    * For some reason WebAppClassLoader.getResource("WEB-INF/wsdl/TestEndpoint.wsdl")
-    * fails when the war is deployed as part of an ear deployment.
-    * 
-    * This ClassLoader falls back to the VFS to find the resource URL. 
-    */
-   static class VirtualFileClassLoader extends ClassLoader
-   {
-      private UnifiedVirtualFile vFile;
-      
-      public VirtualFileClassLoader(UnifiedVirtualFile file, ClassLoader parent)
-      {
-         super(parent);
-         vFile = file;
-      }
-
-      @Override
-      public URL getResource(String name)
-      {
-         URL url = super.getResource(name);
-         if (url == null)
-         {
-            try
-            {
-               url = vFile.findChild(name).toURL();
-            }
-            catch (IOException e)
-            {
-               // ignore
-            }
-         }
-         return url;
-      }
-   }
-}

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBean.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBean.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBean.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -27,16 +27,14 @@
 import java.io.Writer;
 
 /**
- * Metadata model for services.xml 
+ * Metadata model for cxf.xml 
  *
  * @author Thomas.Diesler at jboss.org
  * @since 21-May-2007
  */
 public class DDBean
 {
-   // This will be the name bean. Required. 
    private String beanName;
-   // The class name of the bean. Required. 
    private String beanClass;
 
    public DDBean(String beanName, String beanClass)
@@ -45,30 +43,11 @@
       this.beanClass = beanClass;
    }
 
-   public String getBeanName()
-   {
-      return beanName;
-   }
-
-   public void setBeanName(String beanName)
-   {
-      this.beanName = beanName;
-   }
-
-   public String getBeanClass()
-   {
-      return beanClass;
-   }
-
-   public void setBeanClass(String beanClass)
-   {
-      this.beanClass = beanClass;
-   }
-
    public void writeTo(Writer writer) throws IOException
    {
       writer.write("<bean");
-      writer.write(" name='" + beanName + "'");
+      if (beanName != null)
+         writer.write(" name='" + beanName + "'");
       writer.write(" class='" + beanClass + "'");
       writer.write("></bean>");
    }

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBeans.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDEndpoint.java	                        (rev 0)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDEndpoint.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -0,0 +1,73 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.wsf.stack.xfire.metadata.services;
+
+//$Id$
+
+import java.io.IOException;
+import java.io.Writer;
+
+/**
+ * Metadata model for cxf.xml 
+ *
+ * @author Thomas.Diesler at jboss.org
+ * @since 21-May-2007
+ */
+public class DDEndpoint
+{
+   private String id;
+   private String address;
+   private String implementor;
+   private String invoker;
+
+   public DDEndpoint(String id, String address, String implementor)
+   {
+      this.id = id;
+      this.address = address;
+      this.implementor = implementor;
+   }
+
+   public void setInvoker(String invoker)
+   {
+      this.invoker = invoker;
+   }
+   
+   public void writeTo(Writer writer) throws IOException
+   {
+      writer.write("<jaxws:endpoint id='" + id + "' address='"+ address +"' implementor='" + implementor + "'>");
+      writer.write("<jaxws:properties>");
+      if (invoker != null)
+         writer.write("<entry key='serviceFactory.invoker' value-ref='" + invoker + "'/>");
+      writer.write("</jaxws:properties>");
+      writer.write("</jaxws:endpoint>");
+   }
+
+   public String toString()
+   {
+      StringBuilder str = new StringBuilder("Service");
+      str.append("\n id=" + id);
+      str.append("\n address=" + address);
+      str.append("\n invoker=" + invoker);
+      str.append("\n implementor=" + implementor);
+      return str.toString();
+   }
+}
\ No newline at end of file

Deleted: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDService.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDService.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDService.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -1,131 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.xfire.metadata.services;
-
-//$Id$
-
-import java.io.IOException;
-import java.io.Writer;
-
-/**
- * Metadata model for services.xml 
- *
- * @author Thomas.Diesler at jboss.org
- * @since 21-May-2007
- */
-public class DDService
-{
-   // This will be the name of the service as exposed to the world. Required. 
-   private String name;
-   // The class name of the object you wish to make into a service. Required. 
-   private String serviceClass;
-   // The class name of the implementation which you wish to use when the service is invoked. Optional. 
-   private String implementationClass;
-   // The ServiceFactory controls how the Service is built and configured. Optional. 
-   private String serviceFactory;
-   // The invoker element is optional. It can be used to set a non-default Invoker for a service. 
-   private String invoker;
-
-   public DDService(String name, String serviceClass)
-   {
-      this.name = name;
-      this.serviceClass = serviceClass;
-   }
-
-   public String getName()
-   {
-      return name;
-   }
-
-   public void setName(String name)
-   {
-      this.name = name;
-   }
-
-   public String getServiceClass()
-   {
-      return serviceClass;
-   }
-
-   public void setServiceClass(String serviceClass)
-   {
-      this.serviceClass = serviceClass;
-   }
-
-   public String getImplementationClass()
-   {
-      return implementationClass;
-   }
-
-   public void setImplementationClass(String implementationClass)
-   {
-      this.implementationClass = implementationClass;
-   }
-
-   public String getServiceFactory()
-   {
-      return serviceFactory;
-   }
-
-   public void setServiceFactory(String serviceFactory)
-   {
-      this.serviceFactory = serviceFactory;
-   }
-
-   public String getInvoker()
-   {
-      return invoker;
-   }
-
-   public void setInvoker(String invoker)
-   {
-      this.invoker = invoker;
-   }
-
-   public void writeTo(Writer writer) throws IOException
-   {
-      writer.write("<service>");
-      writer.write("<name>" + name + "</name>");
-      writer.write("<serviceClass>" + serviceClass + "</serviceClass>");
-      if (implementationClass != null)
-         writer.write("<implementationClass>" + implementationClass + "</implementationClass>");
-      if (serviceFactory != null)
-         writer.write("<serviceFactory>" + serviceFactory + "</serviceFactory>");
-      if (invoker != null)
-         writer.write("<invoker>" + invoker + "</invoker>");
-      writer.write("</service>");
-   }
-   
-   public String toString()
-   {
-      StringBuilder str = new StringBuilder("Service");
-      str.append("\n name=" + name);
-      str.append("\n serviceClass=" + serviceClass);
-      if (implementationClass != null)
-         str.append("\n implementationClass=" + implementationClass);
-      if (serviceFactory != null)
-         str.append("\n serviceFactory=" + serviceFactory);
-      if (invoker != null)
-         str.append("\n invoker=" + invoker);
-      return str.toString();
-   }
-}
\ No newline at end of file

Modified: trunk/integration/xfire/src/main/resources/jbossws-xfire-config.xml
===================================================================
--- trunk/integration/xfire/src/main/resources/jbossws-xfire-config.xml	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/resources/jbossws-xfire-config.xml	2007-07-19 18:03:54 UTC (rev 3956)
@@ -29,47 +29,47 @@
   <!-- 
     The stack specific deployment aspects
   --> 
-  <bean name="WSXFireContextPropertiesDeploymentAspect" class="org.jboss.wsf.spi.deployment.ContextPropertiesDeploymentAspect">
+  <bean name="WSCXFContextPropertiesDeploymentAspect" class="org.jboss.wsf.spi.deployment.ContextPropertiesDeploymentAspect">
     <property name="provides">ContextProperties</property>
     <property name="contextProperties">
       <map keyClass="java.lang.String" valueClass="java.lang.String">
-        <entry><key>ServletClass</key><value>org.jboss.wsf.stack.xfire.XFireConfigurableServletExt</value></entry>
+        <entry><key>ServletClass</key><value>org.jboss.wsf.stack.xfire.CXFServletExt</value></entry>
       </map>
     </property>
   </bean>
 
-  <bean name="WSXFireEndpointHandlerDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointHandlerDeploymentAspect">
+  <bean name="WSCXFEndpointHandlerDeploymentAspect" class="org.jboss.wsf.spi.deployment.EndpointHandlerDeploymentAspect">
     <property name="requires">ContainerEndpointHandler</property>
     <property name="provides">StackEndpointHandler</property>
     <property name="requestHandler">org.jboss.wsf.stack.xfire.RequestHandlerImpl</property>
     <property name="lifecycleHandler">org.jboss.wsf.stack.xfire.LifecycleHandlerImpl</property>
   </bean>
 
-  <bean name="WSXFireServicesDeploymentAspect" class="org.jboss.wsf.stack.xfire.XFireServicesDeploymentAspect">
+  <bean name="WSCXFDescriptorDeploymentAspect" class="org.jboss.wsf.stack.xfire.DescriptorDeploymentAspect">
+    <property name="requires">EndpointAddress</property>
     <property name="provides">StackDescriptor</property>
-    <property name="serviceFactory">org.codehaus.xfire.jaxws.JAXWSServiceFactory</property>
     <property name="invokerEJB3">org.jboss.wsf.stack.xfire.InvokerEJB3</property>
     <property name="invokerJSE">org.jboss.wsf.stack.xfire.InvokerJSE</property>
   </bean>
 
   <!-- Deployment aspect installers -->  
-  <bean name="WSMetroDeploymentAspectInstallerJSE" class="org.jboss.wsf.spi.deployment.DeploymentAspectInstaller">
+  <bean name="WSCXFDeploymentAspectInstallerJSE" class="org.jboss.wsf.spi.deployment.DeploymentAspectInstaller">
     <property name="manager"><inject bean="WSDeploymentAspectManagerJSE"/></property>
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
-        <inject bean="WSXFireContextPropertiesDeploymentAspect"/>
-        <inject bean="WSXFireEndpointHandlerDeploymentAspect"/>
-        <inject bean="WSXFireServicesDeploymentAspect"/>
+        <inject bean="WSCXFContextPropertiesDeploymentAspect"/>
+        <inject bean="WSCXFEndpointHandlerDeploymentAspect"/>
+        <inject bean="WSCXFDescriptorDeploymentAspect"/>
       </set>
     </property>
   </bean>
-  <bean name="WSMetroDeploymentAspectInstallerEJB" class="org.jboss.wsf.spi.deployment.DeploymentAspectInstaller">
+  <bean name="WSCXFDeploymentAspectInstallerEJB" class="org.jboss.wsf.spi.deployment.DeploymentAspectInstaller">
     <property name="manager"><inject bean="WSDeploymentAspectManagerEJB"/></property>
     <property name="aspects">
       <set class="java.util.HashSet" elementClass="org.jboss.wsf.spi.deployment.DeploymentAspect">
-        <inject bean="WSXFireContextPropertiesDeploymentAspect"/>
-        <inject bean="WSXFireEndpointHandlerDeploymentAspect"/>
-        <inject bean="WSXFireServicesDeploymentAspect"/>
+        <inject bean="WSCXFContextPropertiesDeploymentAspect"/>
+        <inject bean="WSCXFEndpointHandlerDeploymentAspect"/>
+        <inject bean="WSCXFDescriptorDeploymentAspect"/>
       </set>
     </property>
   </bean>

Modified: trunk/integration/xfire/version.properties
===================================================================
--- trunk/integration/xfire/version.properties	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/version.properties	2007-07-19 18:03:54 UTC (rev 3956)
@@ -1,11 +1,12 @@
 
 # $Id: version.properties 2928 2007-04-26 10:53:56Z thomas.diesler at jboss.com $
 
-sunri.implementation.title=JBoss Web Services - JBossWS/XFire
+sunri.implementation.title=JBoss Web Services - Apache CXF
 
 # Thirdparty library versions
+apache-cxf=2.0
+apache-xml-commons=1.2
 ibm-wsdl4j=1.6.2
 jboss-jaxr=1.2.0.GA
 jboss-security-spi=2.0.0.Beta
-xfire=1.2.6
 

Modified: trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/eardeployment/EarTestCase.java
===================================================================
--- trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/eardeployment/EarTestCase.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/eardeployment/EarTestCase.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -48,11 +48,12 @@
 {
    public static Test suite()
    {
-      String earName = (new JBossWSTestHelper().isTargetJBoss50() ? "jaxws-samples-eardeployment.ear" : "jaxws-samples-eardeployment42.ear");
-      return new JBossWSTestSetup(EarTestCase.class, earName);
+      //String earName = (new JBossWSTestHelper().isTargetJBoss50() ? "jaxws-samples-eardeployment.ear" : "jaxws-samples-eardeployment42.ear");
+      //return new JBossWSTestSetup(EarTestCase.class, earName);
+      return new JBossWSTestSetup(EarTestCase.class, "jaxws-samples-eardeployment.war");
    }
 
-   public void testEJB3Endpoint() throws Exception
+   public void _testEJB3Endpoint() throws Exception
    {
       String soapAddress = "http://" + getServerHost() + ":8080/earejb3/EJB3Bean";
       QName serviceName = new QName("http://eardeployment.jaxws/", "TestEndpointService");




More information about the jbossws-commits mailing list
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerJSE.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/InvokerJSE.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -25,10 +25,14 @@
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.util.List;
 
-import org.codehaus.xfire.MessageContext;
-import org.codehaus.xfire.fault.XFireFault;
-import org.codehaus.xfire.service.invoker.Invoker;
+import org.apache.cxf.frontend.MethodDispatcher;
+import org.apache.cxf.helpers.CastUtils;
+import org.apache.cxf.message.Exchange;
+import org.apache.cxf.service.Service;
+import org.apache.cxf.service.invoker.Invoker;
+import org.apache.cxf.service.model.BindingOperationInfo;
 import org.jboss.wsf.spi.deployment.Endpoint;
 import org.jboss.wsf.spi.deployment.EndpointAssociation;
 import org.jboss.wsf.spi.invocation.Invocation;
@@ -36,22 +40,29 @@
 import org.jboss.wsf.spi.invocation.InvocationHandler;
 
 /**
  * An XFire invoker for JSE
  * 
  * @author Thomas.Diesler at jboss.org
  * @since 21-May-2007
  */
 public class InvokerJSE implements Invoker
 {
-   public Object invoke(Method m, Object[] params, MessageContext context) throws XFireFault
+   public Object invoke(Exchange exchange, Object o)
    {
+      BindingOperationInfo bop = exchange.get(BindingOperationInfo.class);
+      MethodDispatcher md = (MethodDispatcher)exchange.get(Service.class).get(MethodDispatcher.class.getName());
+      Method m = md.getMethod(bop);
+
+      List<Object> paramList = CastUtils.cast((List<?>)o);
+      Object[] params = paramList.toArray();
+
       Endpoint ep = EndpointAssociation.getEndpoint();
       InvocationHandler invHandler = ep.getInvocationHandler();
 
       Invocation inv = invHandler.createInvocation();
       InvocationContext invContext = inv.getInvocationContext();
       //inv.getInvocationContext().addAttachment(WebServiceContext.class, new WebServiceContextJSE(context));
-      invContext.addAttachment(MessageContext.class, context);
+      //invContext.addAttachment(MessageContext.class, context);
       inv.setJavaMethod(m);
       inv.setArgs(params);
 
@@ -76,11 +87,13 @@
       return beanClass.newInstance();
    }
 
-   private void handleException(Exception ex) throws XFireFault
+   private void handleException(Exception ex) 
    {
+      Throwable th = ex;
       if (ex instanceof InvocationTargetException)
-         throw XFireFault.createFault(((InvocationTargetException)ex).getTargetException());
+         th = ((InvocationTargetException)ex).getTargetException();
 
-      throw XFireFault.createFault(ex);
+      throw new RuntimeException(th);
    }
+
 }
\ No newline at end of file
@@ -36,22 +40,29 @@
 
 /**
- * An XFire invoker for JSE
+ * An CXF invoker for JSE
  * 
  * @author Thomas.Diesler at jboss.org

Modified: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/RequestHandlerImpl.java
===================================================================
--- trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBeans.java	2007-07-19 16:09:08 UTC (rev 3955)
+++ trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDBeans.java	2007-07-19 18:03:54 UTC (rev 3956)
@@ -38,7 +38,7 @@
 //$Id$
 
 /**
  * Metadata model for xfire services.xml 
  *
  * @author Thomas.Diesler at jboss.org
  * @since 21-May-2007
@@ -46,20 +46,20 @@
 public class DDBeans
 {
    // The Required services.
-   private List<DDService> services = new ArrayList<DDService>();
+   private List<DDEndpoint> endpoints = new ArrayList<DDEndpoint>();
    // Optional additional beans.
    private List<DDBean> beans = new ArrayList<DDBean>();
    // The derived temp file
    private File tmpFile;
 
-   public List<DDService> getServices()
+   public List<DDEndpoint> getEndpoints()
    {
-      return services;
+      return endpoints;
    }
 
-   public void addService(DDService service)
+   public void addEndpoint(DDEndpoint service)
    {
-      services.add(service);
+      endpoints.add(service);
    }
 
    public List<DDBean> getBeans()
@@ -79,7 +79,7 @@
       try
       {
          File tmpDir = IOUtils.createTempDirectory();
-         tmpFile = File.createTempFile("jbossws-xfire-services", ".xml", tmpDir);
+         tmpFile = File.createTempFile("jbossws-cxf", ".xml", tmpDir);
          Writer writer = new OutputStreamWriter(new FileOutputStream(tmpFile));
          writeTo(writer);
          writer.close();
@@ -103,10 +103,19 @@
 
    public void writeTo(Writer writer) throws IOException
    {
-      writer.write("<beans xmlns='http://xfire.codehaus.org/config/1.0'>");
-      for (DDService service : services)
+      writer.write("<beans " +
+            "xmlns='http://www.springframework.org/schema/beans' " +
+            "xmlns:xsi='http://www.w3.org/2001/XMLSchema-instance' " +
+            "xmlns:beans='http://www.springframework.org/schema/beans' " +
+            "xmlns:jaxws='http://cxf.apache.org/jaxws' " +
+            "xsi:schemaLocation='http://www.springframework.org/schema/beans " +
+            "http://www.springframework.org/schema/beans/spring-beans.xsd " +
+            "http://cxf.apache.org/jaxws " +
+            "http://cxf.apache.org/schemas/jaxws.xsd'>");
+      
+      for (DDEndpoint endpoint : endpoints)
       {
-         service.writeTo(writer);
+         endpoint.writeTo(writer);
       }
       for (DDBean bean : beans)
       {
@@ -38,7 +38,7 @@
 
 /**
- * Metadata model for xfire services.xml 
+ * Metadata model for cxf.xml 
  *
  * @author Thomas.Diesler at jboss.org

Copied: trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDEndpoint.java (from rev 3949, trunk/integration/xfire/src/main/java/org/jboss/wsf/stack/xfire/metadata/services/DDService.java)
===================================================================